"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destructureSchema = void 0;
const formatName_1 = require("../filters/format/formatName");
const typing_1 = require("./typing");
function destructureSchema(schema, options, first = true) {
    const destructuredSchema = [];
    if (schema.type === 'array' && first) {
        destructuredSchema.push({
            name: (0, formatName_1.formatName)(schema.title ?? 'default', false),
            description: schema.description,
            declaration: (0, typing_1.generateTyping)(schema, {
                inline: true,
                resolveDirectly: false,
                context: options?.context,
                prefixDirectlyResolved: options?.prefixDirectlyResolved,
            }).typeDeclaration,
            required: true,
            top: true,
        });
    }
    if (schema.allOf) {
        for (const s of schema.allOf) {
            destructuredSchema.push(...destructureSchema(s, options, false));
        }
    }
    if (schema.properties) {
        for (const propertyName in schema.properties) {
            const property = schema.properties[propertyName];
            destructuredSchema.push({
                name: propertyName,
                description: property.description,
                declaration: (0, typing_1.generateTyping)(property, {
                    inline: true,
                    resolveDirectly: true,
                    context: options?.context,
                    prefixDirectlyResolved: options?.prefixDirectlyResolved,
                }).typeDeclaration,
                required: schema.required ? schema.required.includes(propertyName) : false,
                top: false,
            });
        }
    }
    return destructuredSchema;
}
exports.destructureSchema = destructureSchema;
//# sourceMappingURL=destructure.js.map